@@ -29,6 +29,7 @@ from mypy_boto3_codeguru_reviewer.type_defs import (
     ListRecommendationFeedbackResponseTypeDef,
     ListRecommendationsResponseTypeDef,
     ListRepositoryAssociationsResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
     RepositoryTypeDef,
 )
 
@@ -62,22 +63,25 @@ class Exceptions:
 
 class CodeGuruReviewerClient:
     """
-    [CodeGuruReviewer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
+    [CodeGuruReviewer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client)
     """
 
     meta: ClientMeta
     exceptions: Exceptions
 
     def associate_repository(
-        self, Repository: RepositoryTypeDef, ClientRequestToken: str = None
+        self,
+        Repository: RepositoryTypeDef,
+        ClientRequestToken: str = None,
+        Tags: Dict[str, str] = None,
     ) -> AssociateRepositoryResponseTypeDef:
         """
-        [Client.associate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
+        [Client.associate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.associate_repository)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.can_paginate)
         """
 
     def create_code_review(
@@ -88,31 +92,31 @@ class CodeGuruReviewerClient:
         ClientRequestToken: str = None,
     ) -> CreateCodeReviewResponseTypeDef:
         """
-        [Client.create_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
+        [Client.create_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.create_code_review)
         """
 
     def describe_code_review(self, CodeReviewArn: str) -> DescribeCodeReviewResponseTypeDef:
         """
-        [Client.describe_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
+        [Client.describe_code_review documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_code_review)
         """
 
     def describe_recommendation_feedback(
         self, CodeReviewArn: str, RecommendationId: str, UserId: str = None
     ) -> DescribeRecommendationFeedbackResponseTypeDef:
         """
-        [Client.describe_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
+        [Client.describe_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_recommendation_feedback)
         """
 
     def describe_repository_association(
         self, AssociationArn: str
     ) -> DescribeRepositoryAssociationResponseTypeDef:
         """
-        [Client.describe_repository_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
+        [Client.describe_repository_association documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.describe_repository_association)
         """
 
     def disassociate_repository(self, AssociationArn: str) -> DisassociateRepositoryResponseTypeDef:
         """
-        [Client.disassociate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
+        [Client.disassociate_repository documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.disassociate_repository)
         """
 
     def generate_presigned_url(
@@ -123,7 +127,7 @@ class CodeGuruReviewerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.generate_presigned_url)
         """
 
     def list_code_reviews(
@@ -138,7 +142,7 @@ class CodeGuruReviewerClient:
         NextToken: str = None,
     ) -> ListCodeReviewsResponseTypeDef:
         """
-        [Client.list_code_reviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
+        [Client.list_code_reviews documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_code_reviews)
         """
 
     def list_recommendation_feedback(
@@ -150,14 +154,14 @@ class CodeGuruReviewerClient:
         RecommendationIds: List[str] = None,
     ) -> ListRecommendationFeedbackResponseTypeDef:
         """
-        [Client.list_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
+        [Client.list_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendation_feedback)
         """
 
     def list_recommendations(
         self, CodeReviewArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListRecommendationsResponseTypeDef:
         """
-        [Client.list_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
+        [Client.list_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_recommendations)
         """
 
     def list_repository_associations(
@@ -165,14 +169,21 @@ class CodeGuruReviewerClient:
         ProviderTypes: List[
             Literal["CodeCommit", "GitHub", "Bitbucket", "GitHubEnterpriseServer"]
         ] = None,
-        States: List[Literal["Associated", "Associating", "Failed", "Disassociating"]] = None,
+        States: List[
+            Literal["Associated", "Associating", "Failed", "Disassociating", "Disassociated"]
+        ] = None,
         Names: List[str] = None,
         Owners: List[str] = None,
         MaxResults: int = None,
         NextToken: str = None,
     ) -> ListRepositoryAssociationsResponseTypeDef:
         """
-        [Client.list_repository_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
+        [Client.list_repository_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_repository_associations)
+        """
+
+    def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
+        """
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.list_tags_for_resource)
         """
 
     def put_recommendation_feedback(
@@ -182,12 +193,22 @@ class CodeGuruReviewerClient:
         Reactions: List[Literal["ThumbsUp", "ThumbsDown"]],
     ) -> Dict[str, Any]:
         """
-        [Client.put_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
+        [Client.put_recommendation_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.put_recommendation_feedback)
+        """
+
+    def tag_resource(self, resourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
+        """
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.tag_resource)
+        """
+
+    def untag_resource(self, resourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
+        """
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Client.untag_resource)
         """
 
     def get_paginator(
         self, operation_name: Literal["list_repository_associations"]
     ) -> ListRepositoryAssociationsPaginator:
         """
-        [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.21/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
+        [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.24/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
         """
